---
title: Weekly update rejection
labels: cruft-update
---
`cruft` was not able to automatically update the cookiecutter template.
Please run locally `make template-update` and resolve the conflicts before pushing to GitHub.
